@@ -12,6 +12,7 @@ use warnings;
 use Moose;
 use Moose::Util::TypeConstraints;
 
+use Net::Songkick::City;
 use Net::Songkick::MetroArea;
 
 coerce 'Net::Songkick::Venue',
@@ -21,7 +22,13 @@ coerce 'Net::Songkick::Venue',
 has $_ => (
     is => 'ro',
     isa => 'Str',
-) for qw[uri lat id lng displayName];
+) for qw[uri lat id lng displayName street zip phone website capacity description];
+
+has city => (
+    is => 'ro',
+    isa => 'Net::Songkick::City',
+    coerce => 1,
+);
 
 has metroArea => (
     is => 'ro',
@@ -32,6 +39,9 @@ has metroArea => (
 # Backwards compatibility
 sub metro_area { return $_[0]->metroArea }
 
+no Moose;
+__PACKAGE__->meta->make_immutable;
+
 =head1 AUTHOR
 
 Dave Cross <dave@mag-sol.com>
@@ -45,7 +55,7 @@ perl(1), L<http://www.songkick.com/>, L<http://developer.songkick.com/>
 Copyright (C) 2010, Magnum Solutions Ltd.  All Rights Reserved.
 
 This script is free software; you can redistribute it and/or modify it
-under the same terms as Perl itself. 
+under the same terms as Perl itself.
 
 =cut
 
